@@ -42,12 +42,9 @@ sd.0 = r$summary.random$time[1,"sd"]
 print(sd.0)
 
 ## -----------------------------------------------------------------------------
-nm = names(r$joint.hyper)
-nm = nm[-length(nm)]
-print(nm)
-
-## -----------------------------------------------------------------------------
-Design = as.matrix(cbind(r$joint.hyper[, seq_along(nm)], 1))
+summary(r)
+nm <- nrow(r$summary.hyperpar)
+Design = as.matrix(cbind(r$joint.hyper[, seq_len(nm)], 1))
 head(Design)
 
 ## -----------------------------------------------------------------------------
