@@ -1,10 +1,9 @@
 ## ----setup, include=FALSE-----------------------------------------------------
-library(INLA)
 set.seed(123)
-if (file.exists("myinit.R")) source("myinit.R")
+library(INLA)
 inla.setOption(num.threads="1:1")
 inla.setOption(smtp="taucs")
-inla.setOption(inla.mode="experimental")
+if (file.exists("myinit.R")) source("myinit.R")
 knitr::opts_chunk$set(echo = TRUE)
 knitr::opts_chunk$set(fig.path="figures/multinomial/")
 
@@ -73,7 +72,7 @@ print(pois.model$mlik + corr.factor)
 library(Ecdat)
 library(deldir)
 library(sp)
-library(rgeos)
+library(sf)
 library(mvtnorm)
 library(gridExtra)
 library(mlogit)
@@ -309,20 +308,25 @@ id.samples = over(pp,vor)$id
 check = as.integer(length(unique(id.samples)))
 check
 
-## ---- fig.cap=c("Partiotion of the region [0,1]x[0,1], each red point correspond to a different location"), fig.height=5----
+## ---- fig.cap=c("Partition of the region [0,1]x[0,1], each red point correspond to a different location"), fig.height=5----
 # plot the partition and the locations
 plot(vor)
 points(loc, pch = 21, bg = 2, cex = 0.7)
 
 ## ---- message = F, warnings = F-----------------------------------------------
 # adjacency matrix
-ADJ = gTouches(vor, byid = T)
-# marginal variance of each random effect component
-S = diag(n.reg)
+ADJ <- as(st_touches(st_as_sf(vor)), "Matrix")
+# Unscaled precision matrix
+Q_unscaled <- Matrix::Diagonal(n.reg, colSums(ADJ)) - ADJ * 0.99 # CAR
+# marginal inverse standard deviation of each random effect component
+SD_inv <- Matrix::Diagonal(n.reg, 1.0^-1)
+# Std.dev. from the unscaled precision
+SD_scale <- Matrix::Diagonal(n.reg, diag(inla.qinv(Q_unscaled))^0.5)
 # covariance matrix
-cov.matrix = solve(diag(n.reg) - ADJ)%*%S
+prec.matrix <- (SD_inv %*% SD_scale) %*% Q_unscaled %*% (SD_scale %*% SD_inv)
+prec.matrix <- (prec.matrix + t(prec.matrix)) / 2
 # generate the random effect and add it to the SpatialPolygonDataFrame
-vor@data$rand.eff = as.numeric(rmvnorm(1,sigma = cov.matrix))
+vor@data$rand.eff <- as.numeric(inla.qsample(1, prec.matrix, seed = 1234))
 
 
 ## ---- fig.cap=c("Random effect on the partition"), fig.height=4---------------
